@@ -5,6 +5,8 @@ entry_points = [
                 "lotusops = lotusops.cli.lotusops:lotusops",
                 #  autopledge
                 "lotuspledge = lotusops.cli.lotuspledge:lotuspledge",
+                #  show configuration & commands
+                "lotusopsabout = lotusops.cli.lotusopsabout:lotusopsabout",                
 ]
 
 commands = [cmd.strip().replace(" ",'').split('=')[0] for cmd in entry_points]
\ No newline at end of file
