@@ -18,7 +18,7 @@ msg_help = "\n\
 
 def lotuspledge():
     if  len(sys.argv) < 3 or \
-        any(arg.startswith("-h") for arg in sys.argv) or \
+        any(any(arg.startswith(mark) for mark in ["-h","--h","help"]) for arg in sys.argv) or \
         not load_ips(sys.argv[2]): 
             return msg_help
     autopledge(sys.argv[1],sys.argv[2])
@@ -133,7 +133,7 @@ def autopledge(interval,iplst):
         if any("inspect" in arg for arg in sys.argv): break
         import time
         while pledgeable_cnt>=0: 
-            runscript("lotus-miner sectors pledge",isansible=False)
+            print(runscript("lotus-miner sectors pledge",isansible=False))
             pledgeable_cnt-=1
             time.sleep(PLEDGEING_INTEVERAL)
         time.sleep(INSPECT_INTERVAL)
@@ -158,7 +158,7 @@ def chkavailable(ip_process_env_tree):
             workers[job.split()[2]] = [job.split()[1]]
         else: workers[job.split()[2]].append(job.split()[1])
     script='lotus-miner sectors list|egrep "Packing|PreCommit1|PreCommit2|WaitSeed|CommitWait|Committing|FinalizeSector|Removing|RecoveryTimeout"'
-    sectors=runscript(script,isansible=False)
+    sectors=list(filter(None,runscript(script,isansible=False)))
     sstats=set([sector.split()[1] for sector in sectors if not sector.split()[1].isdigit()])
     sstats_precommit="Packing|PreCommit1|PreCommit2".split("|")
     sectors_cnt_queue = len([sector for sector in sectors if any(stat in sector.split()[1] for stat in sstats_precommit)])
@@ -317,4 +317,5 @@ def chkavailable(ip_process_env_tree):
                                 ip_process_env_tree[ip]['MEM']['LOTUS_USEABLE(CNT)'])
 
     import json; print(json.dumps(ip_process_env_tree, indent=4, sort_keys=True))
+    print("CACHED_CNT: {0}, SECTOR_CNT: {1}".format(cached_sectors_cnt,sectors_cnt))
     return cached_sectors_cnt-sectors_cnt
